/*** Program generated file: any edits may be lost ***/
#ifndef C_INSTALL_CC
# define C_INSTALL_CC "cc"
#endif
#ifndef C_INSTALL_CXX
# define C_INSTALL_CXX "c++"
#endif
#ifndef C_INSTALL_CFLAGS
# define C_INSTALL_CFLAGS "-DHAVE_CHICKEN_CONFIG_H -O2 -pipe -I/usr/local/include -DC_ENABLE_PTABLES -DC_NO_PIC_NO_DLL"
#endif
#ifndef C_INSTALL_SHARE_HOME
# define C_INSTALL_SHARE_HOME "/usr/local/share"
#endif
#ifndef C_INSTALL_BIN_HOME
# define C_INSTALL_BIN_HOME "/usr/local/bin"
#endif
#ifndef C_INSTALL_EGG_HOME
# define C_INSTALL_EGG_HOME "/usr/local/share/chicken/1"
#endif
#ifndef C_INSTALL_LIB_HOME
# define C_INSTALL_LIB_HOME "/usr/local/lib"
#endif
#ifndef C_INSTALL_STATIC_LIB_HOME
# define C_INSTALL_STATIC_LIB_HOME "/usr/local/lib"
#endif
#ifndef C_INSTALL_INCLUDE_HOME
# define C_INSTALL_INCLUDE_HOME "/usr/local/include"
#endif
#ifndef C_INSTALL_MORE_LIBS
# define C_INSTALL_MORE_LIBS "-lm  "
#endif
#ifndef C_INSTALL_MORE_STATIC_LIBS
# define C_INSTALL_MORE_STATIC_LIBS "-lm "
#endif
#ifndef C_DEFAULT_TARGET_STACK_SIZE
# define C_DEFAULT_TARGET_STACK_SIZE (128*1024)
#endif
#ifndef C_STACK_GROWS_DOWNWARD
# define C_STACK_GROWS_DOWNWARD (0)
#endif
#ifndef C_TARGET_MORE_LIBS
# define C_TARGET_MORE_LIBS "-lm  "
#endif
#ifndef C_TARGET_MORE_STATIC_LIBS
# define C_TARGET_MORE_STATIC_LIBS "-lm "
#endif
#ifndef C_TARGET_CC
# define C_TARGET_CC "cc"
#endif
#ifndef C_TARGET_CXX
# define C_TARGET_CXX "c++"
#endif
#ifndef C_TARGET_CFLAGS
# define C_TARGET_CFLAGS "-DHAVE_CHICKEN_CONFIG -O2 -pipe -I/usr/local/include -DC_ENABLE_PTABLES -DC_NO_PIC_NO_DLL"
#endif
#ifndef C_CROSS_CHICKEN
# define C_CROSS_CHICKEN 0
#endif
#ifndef C_TARGET_LIB_HOME
# define C_TARGET_LIB_HOME "/usr/local/lib"
#endif
#ifndef C_TARGET_SHARE_HOME
# define C_TARGET_SHARE_HOME "/usr/local/share"
#endif
#ifndef C_TARGET_INCLUDE_HOME
# define C_TARGET_INCLUDE_HOME "/usr/local/include"
#endif
#ifndef C_TARGET_STATIC_LIB_HOME
# define C_TARGET_STATIC_LIB_HOME "/usr/local/lib/lib"
#endif
